# frozen_string_literal: true

require 'sinatra/base'
require 'rack/contrib/try_static'

module HS
  class DevServer
    class << self
      attr_accessor :app, :entry

      def create(config = {})
        self.entry = config[:entry]
        self.app = initialize_application(config)
        set_root_route
        set_chapter_route
        set_module_route
        app
      end

      private

      def initialize_application(config)
        public_folder = config[:public_folder] || 'public'
        hs_public_folder = File.expand_path('../../app/public', __dir__)
        port = config[:port] || '8080'
        bind = config[:bind] || '0.0.0.0'
        create_application(public_folder, hs_public_folder, bind, port)
      end

      def create_application(public_folder, hs_public_folder, bind, port)
        Sinatra.new do
          set(:bind, bind)
          set(:port, port)
          set(:views, File.expand_path('../../app/views', __dir__))
          set(:public_folder, public_folder)
          use(Rack::TryStatic, root: hs_public_folder, urls: %w[/])
        end
      end

      def set_root_route
        entry = self.entry

        app.get '/' do
          @course = HS::Course.load(entry)
          @title = @course.title

          erb :course
        end
      end

      def set_chapter_route
        entry = self.entry

        app.get '/:chapter' do
          @course = HS::Course.load(entry)
          @chapter = @course.find_chapter(params[:chapter])
          @title = @chapter.title

          erb :chapter
        end
      end

      def set_module_route
        entry = self.entry

        app.get '/:chapter/:module' do
          @course = HS::Course.load(entry)
          @chapter = @course.find_chapter(params[:chapter])
          @module = @chapter.find_module(params[:module])
          @title = @module.title

          erb :module
        end
      end
    end
  end
end
