# frozen_string_literal: true

require 'hs/loaders/xml_parser'
require 'hs/loaders/element_loader'

module HS
  module ChapterLoader
    include HS::XMLParser
    include HS::ElementLoader

    CUSTOM_LOADERS = %i[title intro modules].freeze

    def load_chapter(course, xml, &block)
      create_chapter(course, parse_xml(xml), &block)
    end

    private

    def create_chapter(course, data, &block)
      chapter = HS::Chapter.new(course, data.slice(:slug, :review_status))
      data[:_children].each { |child| load_a_part(chapter, child, &block) }
      chapter
    end

    def load_a_part(chapter, child, &block)
      if CUSTOM_LOADERS.include?(child[:_name])
        send("load_#{child[:_name]}", chapter, child, &block)
      else
        element = load_element(child)
        chapter.content << element if element
      end
    end

    def load_title(chapter, child)
      chapter.title = get_text(child)
    end

    def load_intro(chapter, child)
      chapter.intro = load_element(child)
    end

    def load_modules(chapter, child)
      return unless block_given?
      files = child[:_children].map { |m| m[:file] }.compact
      files.each { |file| yield chapter, file }
    end
  end
end
