# frozen_string_literal: true

require 'hs/loaders/xml_parser'
require 'hs/loaders/element_loader'

module HS
  module ModuleLoader
    include HS::XMLParser
    include HS::ElementLoader

    CUSTOM_LOADERS = %i[title intro].freeze

    def load_module(chapter, xml)
      create_module(chapter, parse_xml(xml))
    end

    private

    def create_module(chapter, data)
      mod = HS::Module.new(chapter, data.slice(:slug, :review_status))
      data[:_children].each { |child| load_a_part(mod, child) }
      mod
    end

    def load_a_part(mod, child)
      if CUSTOM_LOADERS.include?(child[:_name])
        send("load_#{child[:_name]}", mod, child)
      else
        element = load_element(child)
        mod.content << element if element
      end
    end

    def load_title(mod, child)
      mod.title = get_text(child)
    end

    def load_intro(mod, child)
      mod.intro = load_element(child)
    end
  end
end
