# frozen_string_literal: true

require 'hs/loaders/course_loader'

module HS
  # {HS::Course} is a top level model for a course.
  class Course
    extend HS::CourseLoader

    # Load course from given XML file.
    def self.load(file)
      dir = File.dirname(file)

      load_course(File.read(file)) do |course, chapter_file|
        path = "#{dir}/#{chapter_file}"
        course.chapters << HS::Chapter.load(course, path)
      end
    end

    attr_accessor :slug, :title
    attr_reader :chapters

    def initialize(args)
      @chapters = []

      args.each do |key, val|
        instance_variable_set("@#{key}", val)
      end
    end

    # Tries to find chapter in this course by chapter slug.
    def find_chapter(slug)
      chapters.find { |c| c.slug.to_s == slug.to_s }
    end

    # URL of this course when published.
    def hs_url
      "#{HS::Config.publish_url}/learn/#{slug}"
    end
  end
end
