# frozen_string_literal: true

module HS
  module ReviewStatus
    # Possible values for review status:
    #
    # - `none` not reviewed and/or not translated, needs edit or translation
    # - `translated` initial translatation was done, needs edit
    # - `first` first editorial review was done
    # - `second` second editorial review was done
    # - `final` final editorial review was done
    REVIEW_STATUSES = %w[none translated first second final].freeze

    attr_writer :review_status

    def review_status
      return 'none' unless REVIEW_STATUSES.include?(@review_status)
      @review_status
    end
  end
end
