# frozen_string_literal: true

require 'cgi'

module HS
  module ElementPreview
    def text_preview(text)
      return unless text
      CGI.escapeHTML(text)
    end

    def element_preview(tag_name, params, children)
      [
        element_start(tag_name, params, children),
        element_content(children),
        element_end(tag_name, children)
      ].join
    end

    def wrap_into_tag(tag_name, params)
      children = yield
      [
        element_start(tag_name, params, children),
        children.join(''),
        element_end(tag_name, children)
      ].join
    end

    private

    def element_start(tag, params, children)
      start = "<#{tag}"

      unless params.empty?
        params_str = params.map { |k, v| "#{k}=\"#{v}\"" }.join(' ')
        start = "#{start} #{params_str}"
      end

      return "#{start} />" if children.empty?
      "#{start}>"
    end

    def element_content(children)
      return if children.empty?
      children.map(&:preview).compact.join
    end

    def element_end(tag, children)
      return if children.empty?

      "</#{tag}>"
    end
  end
end
